@@ -6,6 +6,9 @@ from .manager_utils import FlanManager
 def get_flan_manager() -> FlanManager:
     """Return singleton FlanManager instance."""
     return FlanManager()
+def get_flan_title(content):
+    mgr = get_flan_manager()
+    return mgr.generate_title(content)
 
 
 def get_flan_summary(
