@@ -1,6 +1,6 @@
 from __future__ import annotations
-import threading,re,urllib.request,m3u8_To_MP4,subprocess,time,yt_dlp
-import os,unicodedata,requests,shutil,tempfile, hashlib,logging,glob
+import threading,re,urllib.request,m3u8_To_MP4,subprocess,time,yt_dlp,fitz
+import os,unicodedata,requests,shutil,tempfile, hashlib,logging,glob,re
 import json,math,pytesseract,cv2,PyPDF2,argparse,sys,whisper,pytesseract
 import os,pytesseract,cv2,pysrt, threading, logging
 from m3u8 import M3U8  # Install: pip install m3u8
@@ -20,8 +20,8 @@ from typing import *
 from .constants import *
 import multiprocessing as mproc
 import moviepy.editor as mp
-
 from pathlib import Path
+from abstract_hugpy.hugpy_console.hugpy_zerosearch_flask_app.deep_zero_manager import deep_zero_generate
 from tqdm import tqdm
 import speech_recognition as sr
 from moviepy.editor import *
